@@ -3,8 +3,8 @@ Utility functions.
 '''
 import logging
 from pathlib import Path
-from contextlib import contextmanager,redirect_stderr,redirect_stdout
-from os import devnull
+# from contextlib import contextmanager,redirect_stderr,redirect_stdout
+# from os import devnull
 from collections.abc import MutableMapping
 # from numpy_groupies.aggregate_numpy import aggregate
 import numpy as np
